.notification-icon-container{padding:30px}.text-icon-link-close-container{display:flex;justify-content:space-evenly;align-items:center;box-shadow:0 4px #3896de;font-size:14px;border-radius:4px;width:70%;padding:20px 20px 20px 10px;font-family:cursive}.material-icons{color:#3896de}.close-button{cursor:pointer;padding-left:14px}div[className=test]:empty{display:none}@media (max-width:600px){.text-icon-link-close-container{font-size:9px;width:90%}}@media (max-width:420px){.text-icon-link-close-container{font-size:8px;width:80%}}@media (max-width:290px){.text-icon-link-close-container{font-size:6.5px;width:100%}}@font-face{font-family:"Material Icons";font-style:normal;font-weight:400;src:url(https://fonts.gstatic.com/s/materialicons/v121/flUhRq6tzZclQEJ-Vdg-IuiaDsNc.woff2) format("woff2")}.material-icons{font-family:"Material Icons";font-weight:400;font-style:normal;font-size:24px;line-height:1;letter-spacing:normal;text-transform:none;display:inline-block;white-space:nowrap;word-wrap:normal;direction:ltr;-webkit-font-feature-settings:"liga";-webkit-font-smoothing:antialiased}
/*# sourceMappingURL=main.09925b4c.chunk.css.map */