self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "45479e567ea250cd912911c92d55ab95",
    "url": "./index.html"
  },
  {
    "revision": "84b21d544307cb458e3b",
    "url": "./static/css/main.09925b4c.chunk.css"
  },
  {
    "revision": "b6a19adb9585ec53bd31",
    "url": "./static/js/2.f9b5f23c.chunk.js"
  },
  {
    "revision": "3dc2da520b7611f998bec3f8b32ee24e",
    "url": "./static/js/2.f9b5f23c.chunk.js.LICENSE.txt"
  },
  {
    "revision": "84b21d544307cb458e3b",
    "url": "./static/js/main.0b644239.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);