(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{19:function(e,t,n){e.exports=n(56)},26:function(e,t,n){},27:function(e,t,n){},56:function(e,t,n){"use strict";n.r(t);var a=n(5),c=n.n(a),s=n(17),i=n.n(s),o=n(0),l=n(1),r=n(2),m=n(3),u=n(13),p=(n(26),n(27),n(8)),b=function(e){Object(r.a)(n,e);var t=Object(m.a)(n);function n(){var e;Object(l.a)(this,n);for(var a=arguments.length,s=new Array(a),i=0;i<a;i++)s[i]=arguments[i];return(e=t.call.apply(t,[this].concat(s))).state={show:!1},e.render=function(){var t=e.props.args.icon,n=e.props.args.textDisplay,a=e.props.args.externalLink,s=e.props.args.url,i=e.props.args.styles||{};return c.a.createElement("div",{className:"notification-icon-container"},c.a.createElement("div",{className:"test"},"hi",c.a.createElement("div",null)),c.a.createElement("div",Object.assign({className:"text-icon-link-close-container"},Object(p.style)(i["text-icon-link-close-container"])),c.a.createElement("i",Object.assign({className:"material-icons"},Object(p.style)(i["material-icons"])),t),c.a.createElement("div",Object.assign({className:"notification-text"},Object(p.style)(i["notification-text"])),n),c.a.createElement("a",Object.assign({className:"link",href:s},Object(p.style)(i.link),{target:"_blank"}),a),c.a.createElement("div",Object.assign({className:"close-button",onClick:function(){document.querySelector("div").style.display="none",e.onClicked()}},Object(p.style)(i["close-button"])),"x")))},e.onClicked=function(){u.a.setComponentValue("")},e.showTitle=function(){e.setState((function(e){return{show:!0}}))},e}return Object(o.a)(n)}(u.b),d=Object(u.c)(b);i.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(d,null)),document.getElementById("root"))}},[[19,1,2]]]);
//# sourceMappingURL=main.0b644239.chunk.js.map